@@ -21,7 +21,8 @@
 #include "config.h"
 #include "ephy-form-auth-data.h"
 
-#include "ephy-string.h"
+#include "ephy-debug.h"
+#include "ephy-uri-helpers.h"
 
 #include <glib/gi18n.h>
 #include <libsoup/soup.h>
@@ -42,23 +43,6 @@ ephy_form_auth_data_get_password_schema (void)
   return &schema;
 }
 
-static void
-normalize_and_prepare_uri (SoupURI *uri,
-                           gboolean remove_path)
-{
-  g_assert (uri != NULL);
-
-  /* We normalize https? schemes here so that we use passwords
-   * we stored in https sites in their http counterparts, and
-   * vice-versa. */
-  if (uri->scheme == SOUP_URI_SCHEME_HTTPS)
-    soup_uri_set_scheme (uri, SOUP_URI_SCHEME_HTTP);
-
-  soup_uri_set_query (uri, NULL);
-  if (remove_path)
-    soup_uri_set_path (uri, "/");
-}
-
 static GHashTable *
 ephy_form_auth_data_get_secret_attributes_table (const char *uri,
                                                  const char *field_username,
@@ -66,10 +50,14 @@ ephy_form_auth_data_get_secret_attributes_table (const char *uri,
                                                  const char *username)
 {
   GHashTable *attributes;
+  char *origin;
+
+  origin = ephy_uri_to_security_origin (uri);
   attributes = secret_attributes_build (EPHY_FORM_PASSWORD_SCHEMA,
-                                        URI_KEY, uri,
+                                        URI_KEY, origin,
                                         username ? USERNAME_KEY : NULL, username,
                                         NULL);
+  g_free (origin);
 
   if (field_username)
     g_hash_table_insert (attributes, g_strdup (FORM_USERNAME_KEY), g_strdup (field_username));
@@ -104,10 +92,9 @@ ephy_form_auth_data_store (const char         *uri,
                            GAsyncReadyCallback callback,
                            gpointer            userdata)
 {
-  SoupURI *fake_uri;
-  char *fake_uri_str;
   SecretValue *value;
   GHashTable *attributes;
+  char *origin;
   char *label;
   GTask *task;
 
@@ -116,32 +103,27 @@ ephy_form_auth_data_store (const char         *uri,
   g_return_if_fail (!form_username || username);
   g_return_if_fail (!form_password || password);
 
-  fake_uri = soup_uri_new (uri);
-  g_return_if_fail (fake_uri);
+  LOG ("Storing password in secret service for uri=%s form_username=%s form_password=%s username=%s",
+       uri, form_username, form_password, username);
 
   task = g_task_new (NULL, NULL, callback, userdata);
 
-  /* Mailman passwords need the full URI */
-  if (!form_username && g_strcmp0 (form_password, "adminpw") == 0)
-    normalize_and_prepare_uri (fake_uri, FALSE);
-  else
-    normalize_and_prepare_uri (fake_uri, TRUE);
-  fake_uri_str = soup_uri_to_string (fake_uri, FALSE);
   value = secret_value_new (password, -1, "text/plain");
-  attributes = ephy_form_auth_data_get_secret_attributes_table (fake_uri_str, form_username,
+  attributes = ephy_form_auth_data_get_secret_attributes_table (uri, form_username,
                                                                 form_password, username);
+  origin = ephy_uri_to_security_origin (uri);
   if (username != NULL) {
     /* Translators: The first %s is the username and the second one is the
-     * hostname where this is happening. Example: gnome@gmail.com and
-     * mail.google.com.
+     * security origin where this is happening. Example: gnome@gmail.com and
+     * https://mail.google.com.
      */
     label = g_strdup_printf (_("Password for %s in a form in %s"),
-                             username, fake_uri_str);
+                             username, origin);
   } else {
-    /* Translators: The first %s is the hostname where this is happening.
-     * Example: mail.google.com.
+    /* Translators: The first %s is the security origin where this is happening.
+     * Example: https://mail.google.com.
      */
-    label = g_strdup_printf (_("Password in a form in %s"), fake_uri_str);
+    label = g_strdup_printf (_("Password in a form in %s"), origin);
   }
   secret_service_store (NULL, EPHY_FORM_PASSWORD_SCHEMA,
                         attributes, NULL, label, value,
@@ -152,8 +134,7 @@ ephy_form_auth_data_store (const char         *uri,
   g_free (label);
   secret_value_unref (value);
   g_hash_table_unref (attributes);
-  soup_uri_free (fake_uri);
-  g_free (fake_uri_str);
+  g_free (origin);
   g_object_unref (task);
 }
 
@@ -202,17 +183,20 @@ search_form_data_cb (SecretService                *service,
     goto out;
   }
 
-  if (!results)
+  if (!results) {
+    LOG ("...secret service query returned no result.");
     goto out;
+  }
 
   item = (SecretItem *)results->data;
   attributes = secret_item_get_attributes (item);
   username = g_hash_table_lookup (attributes, USERNAME_KEY);
   value = secret_item_get_secret (item);
   password = secret_value_get (value, NULL);
-
   g_list_free_full (results, (GDestroyNotify)g_object_unref);
 
+  LOG ("...secret service query returned a password for username=%s.", username);
+
  out:
   if (closure->callback)
     closure->callback (username, password, closure->data);
@@ -234,24 +218,15 @@ ephy_form_auth_data_query (const char                   *uri,
                            gpointer                      user_data,
                            GDestroyNotify                destroy_data)
 {
-  SoupURI *key;
-  char *key_str;
   EphyFormAuthDataQueryClosure *closure;
   GHashTable *attributes;
 
   g_return_if_fail (uri);
 
-  key = soup_uri_new (uri);
-  g_return_if_fail (key);
+  LOG ("Querying secret service for uri=%s form_username=%s form_password=%s username=%s...",
+       uri, form_username, form_password, username);
 
-  if (!form_username && g_strcmp0 (form_password, "adminpw") == 0)
-    normalize_and_prepare_uri (key, FALSE);
-  else
-    normalize_and_prepare_uri (key, TRUE);
-
-  key_str = soup_uri_to_string (key, FALSE);
-
-  attributes = ephy_form_auth_data_get_secret_attributes_table (key_str,
+  attributes = ephy_form_auth_data_get_secret_attributes_table (uri,
                                                                 form_username,
                                                                 form_password,
                                                                 username);
@@ -269,8 +244,6 @@ ephy_form_auth_data_query (const char                   *uri,
                          closure);
 
   g_hash_table_unref (attributes);
-  soup_uri_free (key);
-  g_free (key_str);
 }
 
 static EphyFormAuthData *
@@ -299,9 +272,9 @@ ephy_form_auth_data_free (EphyFormAuthData *data)
 }
 
 static void
-screcet_service_search_finished (SecretService         *service,
-                                 GAsyncResult          *result,
-                                 EphyFormAuthDataCache *cache)
+secret_service_search_finished (SecretService         *service,
+                                GAsyncResult          *result,
+                                EphyFormAuthDataCache *cache)
 {
   GList *results, *p;
   GError *error = NULL;
@@ -316,19 +289,18 @@ screcet_service_search_finished (SecretService         *service,
   for (p = results; p; p = p->next) {
     SecretItem *item = (SecretItem *)p->data;
     GHashTable *attributes;
-    char *host;
 
     attributes = secret_item_get_attributes (item);
-    host = ephy_string_get_host_name (g_hash_table_lookup (attributes, URI_KEY));
-    ephy_form_auth_data_cache_add (cache, host,
+    ephy_form_auth_data_cache_add (cache,
+                                   g_hash_table_lookup (attributes, URI_KEY),
                                    g_hash_table_lookup (attributes, FORM_USERNAME_KEY),
                                    g_hash_table_lookup (attributes, FORM_PASSWORD_KEY),
                                    g_hash_table_lookup (attributes, USERNAME_KEY));
-
-    g_free (host);
     g_hash_table_unref (attributes);
   }
 
+  LOG ("...successfully initialized form auth data cache.");
+
   g_list_free_full (results, g_object_unref);
 }
 
@@ -337,13 +309,15 @@ ephy_form_auth_data_cache_init (EphyFormAuthDataCache *cache)
 {
   GHashTable *attributes;
 
+  LOG ("Initializing form auth data cache %p...", cache);
+
   attributes = secret_attributes_build (EPHY_FORM_PASSWORD_SCHEMA, NULL);
   secret_service_search (NULL,
                          EPHY_FORM_PASSWORD_SCHEMA,
                          attributes,
                          SECRET_SEARCH_UNLOCK | SECRET_SEARCH_ALL,
                          NULL,
-                         (GAsyncReadyCallback)screcet_service_search_finished,
+                         (GAsyncReadyCallback)secret_service_search_finished,
                          cache);
   g_hash_table_unref (attributes);
 }
@@ -396,23 +370,34 @@ ephy_form_auth_data_cache_add (EphyFormAuthDataCache *cache,
 {
   EphyFormAuthData *data;
   GSList *l;
+  char *origin;
 
   g_return_if_fail (cache);
   g_return_if_fail (uri);
 
+  LOG ("Adding uri=%s form_username=%s form_password=%s username=%s to form auth data cache %p",
+       uri, form_username, form_password, username, cache);
+
   data = ephy_form_auth_data_new (form_username, form_password, username);
-  l = g_hash_table_lookup (cache->form_auth_data_map, uri);
+  origin = ephy_uri_to_security_origin (uri);
+  l = g_hash_table_lookup (cache->form_auth_data_map, origin);
   l = g_slist_append (l, data);
-  g_hash_table_replace (cache->form_auth_data_map,
-                        g_strdup (uri), l);
+  g_hash_table_replace (cache->form_auth_data_map, origin, l);
 }
 
 GSList *
 ephy_form_auth_data_cache_get_list (EphyFormAuthDataCache *cache,
                                     const char            *uri)
 {
+  char *origin;
+  GSList *list;
+
   g_return_val_if_fail (cache, NULL);
   g_return_val_if_fail (uri, NULL);
 
-  return g_hash_table_lookup (cache->form_auth_data_map, uri);
+  origin = ephy_uri_to_security_origin (uri);
+  list = g_hash_table_lookup (cache->form_auth_data_map, origin);
+  g_free (origin);
+
+  return list;
 }
