@@ -19,7 +19,11 @@
  */
 
 #include "config.h"
+
 #include "ephy-embed-utils.h"
+#include "ephy-file-helpers.h"
+#include "ephy-shell.h"
+
 #include <glib.h>
 #include <gtk/gtk.h>
 
@@ -129,6 +133,9 @@ main (int argc, char *argv[])
   guint i;
   gtk_test_init (&argc, &argv);
 
+  ephy_file_helpers_init (NULL, EPHY_FILE_HELPERS_PRIVATE_PROFILE, NULL);
+  _ephy_shell_create_instance (EPHY_EMBED_SHELL_MODE_TEST);
+
   for (i = 0; i < G_N_ELEMENTS (tests_has_scheme); i++) {
     SchemeTest test;
     char *test_name;
